# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`facter_conf`](#facter_conf): A class for configuring facter.conf

### Tasks

* [`clear_facter_cache_data`](#clear_facter_cache_data): A task for clearing out facter cache
* [`delete_facter_conf`](#delete_facter_conf): A task for deleting facter.conf.  This is useful for when Puppet/Facter runs are failing due to a malformed/incorrect facter.conf file

## Classes

### <a name="facter_conf"></a>`facter_conf`

Configures facter.conf based on settings available at https://www.puppet.com/docs/puppet/latest/configuring_facter.html

#### Examples

##### 

```puppet
include facter_conf
```

#### Parameters

The following parameters are available in the `facter_conf` class:

* [`facter_conf_ensure`](#-facter_conf--facter_conf_ensure)
* [`config_path`](#-facter_conf--config_path)
* [`owner`](#-facter_conf--owner)
* [`group`](#-facter_conf--group)
* [`mode`](#-facter_conf--mode)
* [`facts_blocklist`](#-facter_conf--facts_blocklist)
* [`facts_ttls`](#-facter_conf--facts_ttls)
* [`global_external_dir`](#-facter_conf--global_external_dir)
* [`global_custom_dir`](#-facter_conf--global_custom_dir)
* [`global_no_external_facts`](#-facter_conf--global_no_external_facts)
* [`global_no_custom_facts`](#-facter_conf--global_no_custom_facts)
* [`global_no_ruby`](#-facter_conf--global_no_ruby)
* [`cli_debug`](#-facter_conf--cli_debug)
* [`cli_trace`](#-facter_conf--cli_trace)
* [`cli_verbose`](#-facter_conf--cli_verbose)
* [`cli_log_level`](#-facter_conf--cli_log_level)
* [`fact_groups`](#-facter_conf--fact_groups)

##### <a name="-facter_conf--facter_conf_ensure"></a>`facter_conf_ensure`

Data type: `Enum[present,absent]`

Sets whether to ensure facter.conf is present or absent

Default value: `present`

##### <a name="-facter_conf--config_path"></a>`config_path`

Data type: `String[1]`

Path for configuring facter.conf

Default value: `'/etc/puppetlabs/facter'`

##### <a name="-facter_conf--owner"></a>`owner`

Data type: `String[1]`

Owner of facter.conf file

Default value: `'root'`

##### <a name="-facter_conf--group"></a>`group`

Data type: `String[1]`

Group of facter.conf file

Default value: `'root'`

##### <a name="-facter_conf--mode"></a>`mode`

Data type: `String[1]`

Mode of facter.conf file

Default value: `'0644'`

##### <a name="-facter_conf--facts_blocklist"></a>`facts_blocklist`

Data type: `Optional[Array[String[1]]]`

Optional array for setting facts to block

Default value: `undef`

##### <a name="-facter_conf--facts_ttls"></a>`facts_ttls`

Data type: `Optional[Array[Hash]]`

Optional array of hashes for setting the time to live (ttl) for given facts.  This will cache the facts listed for the given duration.

Default value: `undef`

##### <a name="-facter_conf--global_external_dir"></a>`global_external_dir`

Data type: `Optional[Array[String[1]]]`

Optional array of paths to search in for external facts

Default value: `undef`

##### <a name="-facter_conf--global_custom_dir"></a>`global_custom_dir`

Data type: `Optional[Array[String[1]]]`

Optional array of paths to search in for custom facts

Default value: `undef`

##### <a name="-facter_conf--global_no_external_facts"></a>`global_no_external_facts`

Data type: `Optional[Boolean]`

Optional boolean. If true, prevents Facter from searching for external facts.

Default value: `undef`

##### <a name="-facter_conf--global_no_custom_facts"></a>`global_no_custom_facts`

Data type: `Optional[Boolean]`

Optional boolean.  If true, prevents Facter from searching for custom facts.

Default value: `undef`

##### <a name="-facter_conf--global_no_ruby"></a>`global_no_ruby`

Data type: `Optional[Boolean]`

Optional boolean.  If true, prevents Facter from loading its Ruby functionality.

Default value: `undef`

##### <a name="-facter_conf--cli_debug"></a>`cli_debug`

Data type: `Optional[Boolean]`

Optional boolean.  If true, Facter outputs debug messages.

Default value: `undef`

##### <a name="-facter_conf--cli_trace"></a>`cli_trace`

Data type: `Optional[Boolean]`

Optional boolean.  If true, Facter prints stacktraces from errors arising in your custom facts.

Default value: `undef`

##### <a name="-facter_conf--cli_verbose"></a>`cli_verbose`

Data type: `Optional[Boolean]`

Optional boolean.  If true, Facter outputs its most detailed messages.

Default value: `undef`

##### <a name="-facter_conf--cli_log_level"></a>`cli_log_level`

Data type:

```puppet
Optional[
    Enum[
      'none',
      'fatal',
      'error',
      'warn',
      'info',
      'debug',
      'trace'
    ]
  ]
```

Sets the minimum level of message severity that gets logged. Valid options: "none", "fatal", "error", "warn", "info", "debug", "trace".

Default value: `undef`

##### <a name="-facter_conf--fact_groups"></a>`fact_groups`

Data type:

```puppet
Optional[
    Array[
      Struct[
        {
          name => String[1],
          facts => Array[String[1]],
        }
      ]
    ]
  ]
```

Definition of custom fact groups which can be used for blocking (blocklist) or caching (ttls) groups of facts.

Default value: `undef`

## Tasks

### <a name="clear_facter_cache_data"></a>`clear_facter_cache_data`

A task for clearing out facter cache

**Supports noop?** false

### <a name="delete_facter_conf"></a>`delete_facter_conf`

A task for deleting facter.conf.  This is useful for when Puppet/Facter runs are failing due to a malformed/incorrect facter.conf file

**Supports noop?** false

